@@ -29,7 +29,7 @@ import (
 	"k8s.io/klog"
 	"sigs.k8s.io/controller-runtime/pkg/client"
 
-	appv1alpha1 "github.com/stolostron/multicloud-operators-placementrule/pkg/apis/apps/v1"
+	appv1alpha1 "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/apis/apps/v1"
 )
 
 func ToPlaceLocal(placement *appv1alpha1.Placement) bool {
@@ -80,11 +80,10 @@ func PlaceByGenericPlacmentFields(kubeclient client.Client, placement appv1alpha
 
 	if err != nil && !errors.IsNotFound(err) {
 		klog.Error("Listing clusters and found error: ", err)
+
 		return nil, err
 	}
 
-	klog.V(2).Infof("listed clusters count: %v, items: %v ", len(cllist.Items), cllist.Items)
-
 	for _, cl := range cllist.Items {
 		// the cluster will not be returned if it is in terminating process
 		if cl.DeletionTimestamp != nil && !cl.DeletionTimestamp.IsZero() {
@@ -92,9 +91,17 @@ func PlaceByGenericPlacmentFields(kubeclient client.Client, placement appv1alpha
 		}
 
 		cl.Namespace = cl.Name
+
+		// reduce memory consumption by cleaning up ManagedFields, Annotations, Finalizers for each managed clustger
+		cl.DeepCopy().SetManagedFields(nil)
+		cl.DeepCopy().SetAnnotations(nil)
+		cl.DeepCopy().SetFinalizers(nil)
+
 		clmap[cl.Name] = cl.DeepCopy()
 	}
 
+	klog.Infof("listed clusters original count: %v", len(cllist.Items))
+
 	return clmap, nil
 }
 
